DayItemSection class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- DayItemSection
Constructors
- DayItemSection({Key? key, required PickerType pickerType, required DateTime date, required bool isSelected, bool isCurrentDate = false, String? price, required VoidCallback onTap, bool isEnabled = true, Color? selectedDayColor, Color? defaultDayColor, Color? currentDayColor, Color? disabledDytColor, Color? selectedDayBorderColor, Color? defaultDayBorderColor, Color? textColor, Color? disabledTextColor, Color? priceColor, Color? betweenRangeColor, bool isBetweenRange = false, required Color primaryColor, required Color primaryContainerColor})
-
const
Properties
- betweenRangeColor → Color?
-
final
- currentDayColor → Color?
-
final
- date → DateTime
-
final
- defaultDayBorderColor → Color?
-
final
- defaultDayColor → Color?
-
final
- disabledDytColor → Color?
-
final
- disabledTextColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBetweenRange → bool
-
final
- isCurrentDate → bool
-
final
- isEnabled → bool
-
final
- isSelected → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onTap → VoidCallback
-
final
- pickerType → PickerType
-
final
- price → String?
-
final
- priceColor → Color?
-
final
- primaryColor → Color
-
final
- primaryContainerColor → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedDayBorderColor → Color?
-
final
- selectedDayColor → Color?
-
final
- textColor → Color?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited